@@ -8,7 +8,7 @@
  */
 
 #include "CDRTransforms.h"
-#include "CDRPath.h"
+
 #include "libcdr_utils.h"
 
 
@@ -23,11 +23,6 @@ libcdr::CDRTransform::CDRTransform(double v0, double v1, double x0, double v3, d
 {
 }
 
-libcdr::CDRTransform::CDRTransform(const CDRTransform &trafo)
-  : m_v0(trafo.m_v0), m_v1(trafo.m_v1), m_x0(trafo.m_x0),
-    m_v3(trafo.m_v3), m_v4(trafo.m_v4), m_y0(trafo.m_y0) {}
-
-
 void libcdr::CDRTransform::applyToPoint(double &x, double &y) const
 {
   double tmpX = m_v0*x + m_v1*y+m_x0;
@@ -209,17 +204,19 @@ double libcdr::CDRTransform::getTranslateY() const
   return y;
 }
 
+librevenge::RVNGString libcdr::CDRTransform::toString() const
+{
+  librevenge::RVNGString output;
+  output.sprintf("[%f %f %f | %f %f %f]", m_v0, m_v1, m_x0, m_v3, m_v4, m_y0);
+  return output;
+}
+
 
 libcdr::CDRTransforms::CDRTransforms()
   : m_trafos()
 {
 }
 
-libcdr::CDRTransforms::CDRTransforms(const CDRTransforms &trafos)
-  : m_trafos(trafos.m_trafos)
-{
-}
-
 libcdr::CDRTransforms::~CDRTransforms()
 {
 }
@@ -246,14 +243,14 @@ bool libcdr::CDRTransforms::empty() const
 
 void libcdr::CDRTransforms::applyToPoint(double &x, double &y) const
 {
-  for (std::vector<CDRTransform>::const_iterator iter = m_trafos.begin(); iter != m_trafos.end(); ++iter)
-    iter->applyToPoint(x,y);
+  for (const auto &trafo : m_trafos)
+    trafo.applyToPoint(x,y);
 }
 
 void libcdr::CDRTransforms::applyToArc(double &rx, double &ry, double &rotation, bool &sweep, double &x, double &y) const
 {
-  for (std::vector<CDRTransform>::const_iterator iter = m_trafos.begin(); iter != m_trafos.end(); ++iter)
-    iter->applyToArc(rx, ry, rotation, sweep, x, y);
+  for (const auto &trafo : m_trafos)
+    trafo.applyToArc(rx, ry, rotation, sweep, x, y);
 }
 
 double libcdr::CDRTransforms::_getScaleX() const
